snowballstemmer: Stemmer algorithms for natural language processing in Python
=============================================================================

Description
-----------

This package provides 29 stemmers for 28 languages generated from Snowball algorithms.

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/snowballstemmer/

This is a pure Python stemming library. If PyStemmer is available, this
module uses it to accelerate.
